@@ -1,27 +1,18 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[2]:
+# In[3]:
 
 
 try:
     if get_ipython().__class__.__name__ == 'ZMQInteractiveShell':
         from IPython.display import display, Javascript
         display(Javascript('Jupyter.notebook.kernel.execute("nb_name = \'" + Jupyter.notebook.notebook_name + "\'");'));
+        display(Javascript('IPython.notebook.save_notebook()'));
 except:
     pass
 
-
-# In[ ]:
-
-
-
-
-
-# In[3]:
-
-
-version = '0.109'
+version = '0.110'
 
 import re
 import tempfile
@@ -36,22 +27,12 @@ import stat
 import pickle
 import time
 
-
-# # Helper Functions
-
-# In[4]:
-
-
 def is_testing():
     try:
         return nb_name == 'lx.ipynb'
     except:
         return False
 
-
-# In[5]:
-
-
 def isnotebook():
     try:
         return get_ipython().__class__.__name__ == 'ZMQInteractiveShell'
@@ -59,18 +40,17 @@ def isnotebook():
         pass
     return False
 
-
-# In[6]:
-
-
 def testPrint(*args):
     if is_testing():
         print(*args)
 
+if is_testing():
+    print("Testing Mode")
+
 
 # # Inspect
 
-# In[7]:
+# In[4]:
 
 
 import inspect
@@ -82,7 +62,7 @@ def debugFunctionName():
     return inspect.stack()[1][3]
 
 
-# In[8]:
+# In[5]:
 
 
 debugGetFileName(), debugGetLineNumber(), debugFunctionName()
@@ -90,7 +70,7 @@ debugGetFileName(), debugGetLineNumber(), debugFunctionName()
 
 # # Shell
 
-# In[9]:
+# In[6]:
 
 
 def shell(cmd):
@@ -103,7 +83,7 @@ def shell(cmd):
     return out
 
 
-# In[10]:
+# In[7]:
 
 
 shell_template = """/bin/bash << EOF 2>&1
@@ -114,16 +94,19 @@ def bash(cmd, lineList=True, do_print=False, remove_last_empty_line=True):
     from subprocess import Popen, PIPE, STDOUT
     p = Popen(cmd, stdout=PIPE, stderr=STDOUT, shell=True)
     out = ""
-    while True:
-        line = p.stdout.readline().decode()
-        out += line
+    try:
+        while True:
+            line = p.stdout.readline().decode()
+            out += line
 
-        if do_print:
-            print(line, end="")
-
-        if not line:
-            break
+            if do_print:
+                print(line, end="")
 
+            if not line:
+                break
+    except KeyboardInterrupt:
+        print("KeyboardInterrupt")
+        
     if remove_last_empty_line and len(out) > 0 and out[-1] == "\n":
         out = out[:-1]
 
@@ -143,13 +126,13 @@ def bash(cmd, lineList=True, do_print=False, remove_last_empty_line=True):
 
 # # Timing
 
-# In[11]:
+# In[8]:
 
 
 timeSinceLastCallDict = {}
 
 
-# In[12]:
+# In[9]:
 
 
 def timeSinceLastCall(name):
@@ -162,14 +145,14 @@ def timeSinceLastCall(name):
     return name + ": " + time_s
 
 
-# In[13]:
+# In[10]:
 
 
 if is_testing():
     print(timeSinceLastCall('test marker'))
 
 
-# In[14]:
+# In[11]:
 
 
 import time
@@ -197,7 +180,7 @@ if is_testing():
 
 # # Requiremtns
 
-# In[15]:
+# In[12]:
 
 
 requirements = []
@@ -229,7 +212,7 @@ import yaml
 
 # # Strings
 
-# In[16]:
+# In[13]:
 
 
 def sFloat0(f): return "{:0.0f}".format(f)
@@ -259,7 +242,7 @@ if is_testing():
     print(sFloatSci5(1.234567))
 
 
-# In[17]:
+# In[14]:
 
 
 def strUuid4():
@@ -270,14 +253,14 @@ def strUuid4():
     return uuid
 
 
-# In[18]:
+# In[15]:
 
 
 if is_testing():
     print(strUuid4())
 
 
-# In[19]:
+# In[16]:
 
 
 def strRand(n, num=True, upperCase=True, lowerCase=True):
@@ -289,7 +272,7 @@ def strRand(n, num=True, upperCase=True, lowerCase=True):
     return ''.join(random.choice(pool) for _ in range(n))
 
 
-# In[20]:
+# In[17]:
 
 
 if is_testing():
@@ -298,7 +281,7 @@ if is_testing():
     print(strRand(20, upperCase=False, lowerCase=False))
 
 
-# In[21]:
+# In[18]:
 
 
 def strMd5Pickle4(obj):
@@ -308,14 +291,14 @@ def strMd5Pickle4(obj):
     return md5.hexdigest()
 
 
-# In[22]:
+# In[19]:
 
 
 if is_testing():
     print(strMd5Pickle4(['a', 'b']))
 
 
-# In[23]:
+# In[20]:
 
 
 def strMd5String(s):
@@ -324,7 +307,7 @@ def strMd5String(s):
     return md5.hexdigest()
 
 
-# In[24]:
+# In[21]:
 
 
 if is_testing():
@@ -333,7 +316,7 @@ if is_testing():
 
 # # Multiprocess / Thread
 
-# In[25]:
+# In[22]:
 
 
 def mapThread(func, args, n=8):
@@ -358,14 +341,14 @@ if is_testing():
 
 # # Lists
 
-# In[26]:
+# In[23]:
 
 
 def liChunks(l, chunk_size):
     return [l[i:i + chunk_size] for i in range(0, len(l), chunk_size)]
 
 
-# In[27]:
+# In[24]:
 
 
 if is_testing():
@@ -374,7 +357,7 @@ if is_testing():
     print(liChunks(['a', 'b', 'c', 'd', 'e', 'f'], 3))
 
 
-# In[28]:
+# In[25]:
 
 
 def liSplit(a, number_of_splits):
@@ -382,7 +365,7 @@ def liSplit(a, number_of_splits):
     return [a[start:end] for start, end in zip(idxs[:-1], idxs[1:])]
 
 
-# In[29]:
+# In[26]:
 
 
 if is_testing():
@@ -394,7 +377,7 @@ if is_testing():
     print(liSplit(['a', 'b', 'c', 'd', 'e'], 6))
 
 
-# In[30]:
+# In[27]:
 
 
 def liJoin(l):
@@ -404,14 +387,14 @@ def liJoin(l):
     return out
 
 
-# In[31]:
+# In[28]:
 
 
 if is_testing():
     print(liJoin([['a', 'b', 'c'], ['d', 'e', 'f']]))
 
 
-# In[32]:
+# In[29]:
 
 
 def liFlatten(l):
@@ -428,7 +411,7 @@ def liFlatten(l):
         return l
 
 
-# In[33]:
+# In[30]:
 
 
 if is_testing():
@@ -438,7 +421,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[34]:
+# In[31]:
 
 
 regex_cache = {}
@@ -448,35 +431,35 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[35]:
+# In[32]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[36]:
+# In[33]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[37]:
+# In[34]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[38]:
+# In[35]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[39]:
+# In[36]:
 
 
 def lCsv(l, force_oneline=False):
@@ -492,21 +475,21 @@ def lCsv(l, force_oneline=False):
     return ", ".join([str(e) for e in l])
 
 
-# In[40]:
+# In[37]:
 
 
 if is_testing():
     print(lCsv(['a', 'b', 1, 3.14]))
 
 
-# In[41]:
+# In[38]:
 
 
 if is_testing():
     print(lCsv([['a', 'b'], 1, 3.14]))
 
 
-# In[42]:
+# In[39]:
 
 
 if is_testing():
@@ -515,7 +498,7 @@ if is_testing():
 
 # # Text files
 
-# In[43]:
+# In[40]:
 
 
 def txtread(path):
@@ -536,7 +519,7 @@ def txtwrite(path, txt):
             return f.write(txt)
 
 
-# In[44]:
+# In[41]:
 
 
 if is_testing():
@@ -545,21 +528,21 @@ if is_testing():
 
 # # YAML files
 
-# In[45]:
+# In[42]:
 
 
 def yamlwrite(path, obj):
     txtwrite(path, yaml.dump(obj, sort_keys=False))
 
 
-# In[46]:
+# In[43]:
 
 
 def yamlread(path):
     return yaml.safe_load(txtread(path=path))
 
 
-# In[47]:
+# In[44]:
 
 
 if is_testing():
@@ -572,7 +555,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[48]:
+# In[45]:
 
 
 regex_cache = {}
@@ -584,35 +567,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[49]:
+# In[46]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[50]:
+# In[47]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[51]:
+# In[48]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[52]:
+# In[49]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[53]:
+# In[50]:
 
 
 if is_testing():
@@ -621,7 +604,7 @@ if is_testing():
 
 # # GCP Google Cloud Platform
 
-# In[54]:
+# In[51]:
 
 
 import warnings
@@ -645,7 +628,7 @@ def _gsBlob(path):
     return blob
 
 
-# In[55]:
+# In[52]:
 
 
 def gsGsToHttp(path):
@@ -655,7 +638,7 @@ def gsHttpToGs(path):
     return path.replace("https://storage.cloud.google.com/", "gs://").split("?")[0] # "?" is for possible "?authuser=0"
 
 
-# In[56]:
+# In[53]:
 
 
 def gsLs(path):
@@ -665,7 +648,7 @@ def gsLs(path):
     return ['gs://' + bucket + '/' + blob.name for blob in client.list_blobs(prefix=prefix)]
 
 
-# In[57]:
+# In[54]:
 
 
 def gsExists(path):
@@ -675,7 +658,7 @@ def gsExists(path):
     return client.blob(prefix).exists()
 
 
-# In[58]:
+# In[55]:
 
 
 def gsUploadFile(gsPath, path):
@@ -683,7 +666,7 @@ def gsUploadFile(gsPath, path):
     blob.upload_from_filename(path)
 
 
-# In[59]:
+# In[56]:
 
 
 def gsTxtread(path):
@@ -695,7 +678,7 @@ def gsTxtread(path):
     return blob.download_as_string().decode()
 
 
-# In[60]:
+# In[57]:
 
 
 def gsTxtwrite(path, s):
@@ -703,7 +686,7 @@ def gsTxtwrite(path, s):
     return blob.upload_from_string(s)
 
 
-# In[61]:
+# In[58]:
 
 
 def gsImwrite(path, img):
@@ -712,7 +695,7 @@ def gsImwrite(path, img):
     blob.upload_from_string(encimg.tobytes())
 
 
-# In[62]:
+# In[59]:
 
 
 def gsImread(path):
@@ -721,7 +704,7 @@ def gsImread(path):
     return cv2.imdecode(raw, 1)[:, :, [2, 1, 0]]
 
 
-# In[63]:
+# In[60]:
 
 
 def gsPklWrite(path, obj):
@@ -729,7 +712,7 @@ def gsPklWrite(path, obj):
     return blob.upload_from_string(pickle.dumps(obj, protocol=4))
 
 
-# In[64]:
+# In[61]:
 
 
 def gsPklRead(path):
@@ -739,7 +722,7 @@ def gsPklRead(path):
 
 # # Pickle
 
-# In[65]:
+# In[62]:
 
 
 def pklwrite(path, obj):
@@ -752,7 +735,7 @@ def pklwrite(path, obj):
             return pickle.dump(obj, f, protocol=4)
 
 
-# In[66]:
+# In[63]:
 
 
 def pklread(path):
@@ -763,7 +746,7 @@ def pklread(path):
             return pickle.load(f)
 
 
-# In[67]:
+# In[64]:
 
 
 if is_testing():
@@ -776,7 +759,7 @@ if is_testing():
 
 # # Images
 
-# In[68]:
+# In[65]:
 
 
 def _imreadSsh(path):
@@ -857,7 +840,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255, mode='constant'):
         raise RuntimeError(f"Mode '{mode}' not found")
 
 
-# In[69]:
+# In[66]:
 
 
 def imscaleNN(img, s):
@@ -869,7 +852,7 @@ def imscaleBic(img, s):
 
 
 
-# In[70]:
+# In[67]:
 
 
 def imshow(array, scale=1, force_nb=False):
@@ -884,14 +867,14 @@ def imshow(array, scale=1, force_nb=False):
         cv2.waitKey()
 
 
-# In[71]:
+# In[68]:
 
 
 def imNewNoise(height, width, scaleNN=1):
     return imscaleNN((255 * np.random.rand(height, width, 3)).astype(np.uint8), scaleNN)
 
 
-# In[72]:
+# In[69]:
 
 
 if is_testing():
@@ -899,7 +882,7 @@ if is_testing():
     imshow(impad(img, bottom=10, right=10, mode='reflect'))
 
 
-# In[73]:
+# In[70]:
 
 
 def imCropUniformBorder(img, color=255):
@@ -938,7 +921,7 @@ if is_testing():
                         raise RuntimeError('Crop did not work for ', i, j, k, l)
 
 
-# In[74]:
+# In[71]:
 
 
 def imDecodeBytes(imBytes):
@@ -949,7 +932,7 @@ def imDecodeBytes(imBytes):
     return img
 
 
-# In[75]:
+# In[72]:
 
 
 #if is_testing():
@@ -957,14 +940,14 @@ def imDecodeBytes(imBytes):
 #    imshow(img)
 
 
-# In[76]:
+# In[73]:
 
 
 #if is_testing():
 #    imshow('http://via.placeholder.com/70.png')
 
 
-# In[77]:
+# In[74]:
 
 
 if is_testing():
@@ -983,7 +966,7 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[78]:
+# In[75]:
 
 
 def imRepeat(img, height, width):
@@ -997,7 +980,7 @@ def imRepeat(img, height, width):
     return img
 
 
-# In[79]:
+# In[76]:
 
 
 if is_testing():
@@ -1005,33 +988,33 @@ if is_testing():
     imshow(imRepeat(img_random_color_3x5, 7, 11), scale=10)
 
 
-# In[80]:
+# In[77]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[81]:
+# In[78]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[82]:
+# In[79]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[83]:
+# In[80]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[84]:
+# In[81]:
 
 
 def imAddNoiseGauss(img, std):
@@ -1043,7 +1026,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imNewWhite(150, 150), 30))
 
 
-# In[85]:
+# In[82]:
 
 
 if is_testing():
@@ -1051,7 +1034,7 @@ if is_testing():
     imshow('/tmp/img.jpg')
 
 
-# In[86]:
+# In[83]:
 
 
 def imJpgDegradation(img, quality):
@@ -1064,7 +1047,7 @@ def imJpgDegradation(img, quality):
 #if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[87]:
+# In[84]:
 
 
 def imCropCenter(img, size):
@@ -1079,35 +1062,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[88]:
+# In[85]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[89]:
+# In[86]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[90]:
+# In[87]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[91]:
+# In[88]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[92]:
+# In[89]:
 
 
 def imCropRandom(img, size, auto_size=True):
@@ -1130,7 +1113,7 @@ def imCropRandom(img, size, auto_size=True):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[93]:
+# In[90]:
 
 
 #if is_testing(): 
@@ -1140,7 +1123,7 @@ def imCropRandom(img, size, auto_size=True):
 #    imshow(imCropRandom(imread('http://via.placeholder.com/40.png'), 41))
 
 
-# In[94]:
+# In[91]:
 
 
 def draw_rect(img, h_beg, h_end, w_beg, w_end, line_width, color=(0, 0, 0)):
@@ -1222,7 +1205,7 @@ def imCropRandomSeed(img, sizes, idx, crop_idx, use_crop=True, use_minimap=False
         return crop
 
 
-# In[95]:
+# In[92]:
 
 
 if is_testing():
@@ -1233,7 +1216,7 @@ if is_testing():
     imshow(imCropRandomSeed(None, (10, 20), idx=0, crop_idx=0, use_crop=True, use_minimap=False), scale=3)
 
 
-# In[96]:
+# In[93]:
 
 
 def imGallery(imgs, pad=0, n_cols=None, n_rows=None, ratio=None):
@@ -1286,7 +1269,7 @@ def imGallery(imgs, pad=0, n_cols=None, n_rows=None, ratio=None):
     return out
 
 
-# In[97]:
+# In[94]:
 
 
 if is_testing():
@@ -1310,7 +1293,7 @@ if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:3], pad=1, ratio=0))
 
 
-# In[98]:
+# In[95]:
 
 
 #if is_testing():
@@ -1318,7 +1301,7 @@ if is_testing():
 #    imshow(imGallery([img40x20, img40x20, img40x20], pad=1))
 
 
-# In[99]:
+# In[96]:
 
 
 def imAddTextHeader(img, text, h=None, size=None):
@@ -1353,7 +1336,7 @@ if is_testing():
     imshow(imAddTextHeader(imNewBlack(100, 100), 'black image'))
 
 
-# In[100]:
+# In[97]:
 
 
 if is_testing():
@@ -1363,7 +1346,7 @@ if is_testing():
 
 # # Video
 
-# In[101]:
+# In[98]:
 
 
 #def imgsToVid(imgs, file_name='out.avi'):
@@ -1383,7 +1366,7 @@ if is_testing():
 #imgsToVid(frames, 'test.avi')
 
 
-# In[102]:
+# In[99]:
 
 
 #ffmpeg -framerate 1/5 -i img%03d.png -c:v libx264 -r 30 -pix_fmt yuv420p out.mp4
@@ -1392,7 +1375,7 @@ if is_testing():
 # ffmpeg -framerate 1/5 -pattern_type glob -i '*.png' -c:v libx264 -r 30 -pix_fmt yuv420p -vf "crop=trunc(iw/2)*2:trunc(ih/2)*2"  ../out.mp4
 
 
-# In[103]:
+# In[100]:
 
 
 def imsToMp4(path, imgs, time_per_image, frame_rate_output_video=30, verbose=0):
@@ -1412,7 +1395,7 @@ if is_testing():
 
 # # pytorch
 
-# In[104]:
+# In[101]:
 
 
 def ptT(img_np_uint8):
@@ -1429,7 +1412,7 @@ def ptUint8(img_tensor):
     
 
 
-# In[105]:
+# In[ ]:
 
 
 if is_testing():
@@ -1441,7 +1424,7 @@ if is_testing():
 
 # # Files
 
-# In[106]:
+# In[ ]:
 
 
 def _fiFindByWildcardSsh(wildcard):
@@ -1462,7 +1445,7 @@ def fiFindImgs(dir_path, recursive=False, ext='png'):
     return fiFindByWildcard(wildcard)
 
 
-# In[107]:
+# In[ ]:
 
 
 import os
@@ -1485,7 +1468,7 @@ if is_testing():
     print(pexpanduser('~/tmp/file.txt'))
 
 
-# In[108]:
+# In[ ]:
 
 
 if is_testing():
@@ -1514,7 +1497,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[109]:
+# In[ ]:
 
 
 def fiRemove(path):
@@ -1542,7 +1525,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[110]:
+# In[ ]:
 
 
 if is_testing():
@@ -1574,7 +1557,7 @@ if is_testing():
         print("files: " + "\n".join(fiFindByWildcard(os.path.join(d, "**", "*"))))
 
 
-# In[111]:
+# In[ ]:
 
 
 def fiUnzip(zip_path, out_dir=None, remove=False):
@@ -1589,7 +1572,7 @@ def fiUnzip(zip_path, out_dir=None, remove=False):
         zip.extractall(out_dir)
 
 
-# In[112]:
+# In[ ]:
 
 
 def fiJoin(*args):
@@ -1601,7 +1584,7 @@ if is_testing():
 
 # # Jupyter
 
-# In[113]:
+# In[ ]:
 
 
 def jnSettings():
@@ -1612,7 +1595,7 @@ if is_testing():
     jnSettings()
 
 
-# In[114]:
+# In[ ]:
 
 
 def jnNbFullWidth():
@@ -1626,7 +1609,7 @@ def jnPandasSettings():
     pd.set_option('display.max_colwidth', 100000)
 
 
-# In[115]:
+# In[ ]:
 
 
 def jnImageRenderingPixelated():
@@ -1638,7 +1621,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[116]:
+# In[ ]:
 
 
 def jnDefault():
@@ -1656,7 +1639,7 @@ if is_testing():
 
 
 
-# In[117]:
+# In[ ]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -1669,7 +1652,7 @@ if is_testing():
     
 
 
-# In[118]:
+# In[ ]:
 
 
 def jnImgToHtmlB64(img):
@@ -1730,7 +1713,7 @@ def jnImageRow(imgs, names=None, width=100, external=False, title_img=None, titl
     display(HTML(html))
 
 
-# In[119]:
+# In[ ]:
 
 
 if is_testing():
@@ -1739,7 +1722,7 @@ if is_testing():
    
 
 
-# In[120]:
+# In[ ]:
 
 
 if is_testing():
@@ -1749,7 +1732,7 @@ if is_testing():
     jnImageRow(imgs, external=True, title='test')
 
 
-# In[121]:
+# In[ ]:
 
 
 
@@ -1757,7 +1740,7 @@ if is_testing():
    jnImageRow(imgs=[imNewBlack(20, 20), imNewBlack(40, 20), imNewBlack(20, 800)])
 
 
-# In[122]:
+# In[ ]:
 
 
 #def dfDisplayWithImgs(df):
@@ -1773,7 +1756,7 @@ if is_testing():
 
 # # GIT
 
-# In[123]:
+# In[ ]:
 
 
 def gitGetHash():
@@ -1783,7 +1766,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[124]:
+# In[ ]:
 
 
 def gitGetBranch():
@@ -1793,7 +1776,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[125]:
+# In[ ]:
 
 
 def gitGetMessage():
@@ -1803,7 +1786,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[126]:
+# In[ ]:
 
 
 def gitGetAllFiles():
@@ -1813,7 +1796,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[127]:
+# In[ ]:
 
 
 def gitListByTime(path=None):
@@ -1829,7 +1812,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[128]:
+# In[ ]:
 
 
 def gitTime(path):
@@ -1840,7 +1823,7 @@ if is_testing():
     print(gitTime("__init__.py"))
 
 
-# In[129]:
+# In[ ]:
 
 
 def gitTimeRaw(path):
@@ -1851,7 +1834,7 @@ if is_testing():
     print(gitTimeRaw("__init__.py"))
 
 
-# In[130]:
+# In[ ]:
 
 
 def shellSortDirsBySize():
@@ -1863,14 +1846,14 @@ if is_testing():
 
 # # Package Files
 
-# In[131]:
+# In[ ]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[132]:
+# In[ ]:
 
 
 def shell(cmd):
@@ -1878,7 +1861,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[133]:
+# In[ ]:
 
 
 if is_testing():
@@ -1910,7 +1893,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[134]:
+# In[ ]:
 
 
 if is_testing():
@@ -1920,7 +1903,7 @@ description-file = README.md
 """
 
 
-# In[135]:
+# In[ ]:
 
 
 if is_testing():
@@ -1943,14 +1926,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[136]:
+# In[ ]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[137]:
+# In[ ]:
 
 
 if is_testing():
@@ -1958,10 +1941,10 @@ if is_testing():
     package_files['lx/__init__.py'] = txtread("lx.py")
     
     output = shell("""python3 -c 'import importlib; lx = importlib.import_module(name=".", package="lx"); print(lx.version)'""")
-    print(output.strip(), 'Version correct: ', output.strip() == version, "(", output.strip(), version, ")")
+    raise RuntimeError(output.strip(), 'Version correct: ', output.strip() == version, "(", output.strip(), version, ")")
 
 
-# In[138]:
+# In[ ]:
 
 
 if is_testing():
@@ -1972,7 +1955,7 @@ lx/__init__.py
 """
 
 
-# In[139]:
+# In[ ]:
 
 
 if is_testing():
